@@ -1473,6 +1473,7 @@ sub make_filter {
         my ($fn, $l) = @_;
         weaken $_[1] if $is_stream;
         lazy_if {
+            no warnings 'recursion';    # XXX this should be tail calling???
             $l = force $l;
             is_null($l) ? $l : do {
                 my ($a, $r) = $l->first_and_rest;
@@ -1519,7 +1520,13 @@ sub list_filter_with_tail;
 sub list_map {
     @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
-    is_null($l) ? $l : cons(scalar &$fn(car $l), list_map($fn, cdr $l))
+    is_null($l) ? $l : cons(
+        scalar &$fn(car $l),
+        do {
+            no warnings 'recursion';
+            list_map($fn, cdr $l)
+        }
+    )
 }
 
 TEST {
@@ -1998,14 +2005,15 @@ TEST {
 sub list_any {
     @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
+    my $v;
 LP: {
         if (is_pair $l) {
-            (&$pred(car $l)) or do {
+            ($v = &$pred(car $l)) or do {
                 $l = cdr $l;
                 redo LP;
             }
         } elsif (is_null $l) {
-            0
+            $v
         } else {
             die "improper list"
         }
@@ -2021,7 +2029,7 @@ TEST {
 TEST {
     list_any sub { $_[0] % 2 }, array_to_list []
 }
-0;
+undef;
 TEST {
     list_any sub { $_[0] % 2 }, array_to_list [2, 5, 8]
 }
