@@ -20,7 +20,7 @@ FunctionalPerl - functional programming in Perl
     use FP::List;
 
     # But you can also import sets of modules from here, e.g.:
-    use FunctionalPerl qw(:sequences :repl);
+    #use FunctionalPerl qw(:sequences :repl);
 
 =head1 DESCRIPTION
 
@@ -137,7 +137,7 @@ our @EXPORT      = ();
 our @EXPORT_OK   = qw(expand_import_tags);
 our %EXPORT_TAGS = ();
 
-our $VERSION = "0.72.69";
+our $VERSION = "0.72.70";
 
 # Export tag to modules and/or other tags; each module will be
 # imported with ":all" by default. Where a module name contains " = ",
